@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -36,6 +36,7 @@ $tableutenti = $PHPR_TAB_PRE."utenti";
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
+$tablecache = $PHPR_TAB_PRE."cache";
 
 
 if (defined("C_UTENTE_BACKUP_ESTERNO") and C_UTENTE_BACKUP_ESTERNO != "" and $utente_backup == C_UTENTE_BACKUP_ESTERNO) $id_utente = "b";
@@ -49,6 +50,8 @@ else $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 $priv_crea_backup = substr($priv_mod_pers,1,1);
+chiudi_query($privilegi_annuali_utente);
+chiudi_query($privilegi_globali_utente);
 } # fine if ($id_utente != 1 and $id_utente != "b")
 else {
 $priv_crea_backup = "s";
@@ -78,8 +81,28 @@ if ($azione == "SI") {
 
 
 if ($crea_backup) {
+include_once("./includes/funzioni_$PHPR_DB_TYPE"."_extra.php");
 
 if ($backup_contratti != "SI") {
+$raggiunto_limite = 0;
+if (defined('C_LIMITE_BACKUP_GIORNALIERI') and C_LIMITE_BACKUP_GIORNALIERI > 0 and $id_utente != "b") {
+$tabelle_lock = array($tablecache);
+$tabelle_lock = lock_tabelle($tabelle_lock);
+$adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+$oggi = substr($adesso,0,10);
+esegui_query("delete from $tablecache where tipo = 'lim_back' and datainserimento < '$oggi 00:00:00' ");
+$lim_back = esegui_query("select * from $tablecache where tipo = 'lim_back' and datainserimento >= '$oggi 00:00:00' ");
+if (!numlin_query($lim_back)) esegui_query("insert into $tablecache (numero,tipo,data_modifica,datainserimento) values ('1','lim_back','$adesso','$adesso') ");
+else {
+$num_lim_back = risul_query($lim_back,0,'numero');
+if ($num_lim_back >= C_LIMITE_BACKUP_GIORNALIERI) $raggiunto_limite = 1;
+else esegui_query("update $tablecache set numero = '".($num_lim_back + 1)."', data_modifica = '$adesso' where tipo = 'lim_back' and datainserimento >= '$oggi 00:00:00' ");
+} # fine else if (!numlin_query($lim_back))
+unlock_tabelle($tabelle_lock);
+} # fine if (defined('C_LIMITE_BACKUP_GIORNALIERI') and C_LIMITE_BACKUP_GIORNALIERI > 0 and $id_utente != "b")
+if ($raggiunto_limite) echo mex("Raggiunto il limite giornaliero di backup",$pag)." (".C_LIMITE_BACKUP_GIORNALIERI.").<br>";
+else {
+
 $anni = esegui_query("select * from $tableanni order by idanni");
 $num_anni = numlin_query($anni);
 
@@ -192,8 +215,9 @@ $num_lock++;
 $altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."cache";
 $num_lock++;
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-if ($id_utente == "b") $file = @fopen(C_DATI_PATH."/backup_ext.php","w+");
-else $file = @fopen(C_DATI_PATH."/hoteld_backup.php","w+");
+if ($id_utente == "b") $nome_file_bk = C_DATI_PATH."/backup_ext.php";
+else $nome_file_bk = C_DATI_PATH."/hoteld_backup.php";
+$file = @fopen($nome_file_bk,"w");
 if ($file) {
 flock($file,2);
 allunga_tempo_limite();
@@ -213,7 +237,7 @@ fwrite($file,"<?php exit(); ?>
 <versione>$versione_corrente</versione>
 <log>$PHPR_LOG</log>
 ");
-$utenti= esegui_query("select idutenti from $tableutenti order by idutenti");
+$utenti = esegui_query("select idutenti from $tableutenti order by idutenti");
 #dump_testo("/dati_connessione.php",$file);
 dump_testo("/lingua.php",$file);
 dump_testo("/unit.php",$file);
@@ -235,6 +259,7 @@ if (@is_file(C_DATI_PATH."/selperiodimenu$anno_reg.$idutente_reg.php")) dump_tes
 } # fine for $num2
 } # fine if (!$anni_backup or ${'anno_sel'.$anno_reg})
 } # fine for $num1
+
 fwrite($file,"<database>
 ");
 dump_tabella("anni",$file,$cond_anni);
@@ -326,6 +351,7 @@ echo mex("File creato",$pag).".<br>
 } # fine if ($file)
 else echo mex("Non ho il permesso di scrittura sul file",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
+} # fine else if ($raggiunto_limite)
 } # fine if ($backup_contratti != "SI")
 
 
@@ -336,7 +362,7 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $nomi_contratti = esegui_query("select valpersonalizza from $PHPR_TAB_PRE"."personalizza where idpersonalizza = 'nomi_contratti' and idutente = '1'");
 $nomi_contratti = risul_query($nomi_contratti,0,'valpersonalizza');
 esegui_query("insert into $PHPR_TAB_PRE"."contratti (numero,tipo,testo) values ('1','nomi_con','".aggslashdb($nomi_contratti)."')");
-$file = @fopen(C_DATI_PATH."/hoteld_doc_backup.php","w+");
+$file = @fopen(C_DATI_PATH."/hoteld_doc_backup.php","w");
 if ($file) {
 flock($file,2);
 $versione_corrente = esegui_query("select * from $tableversioni where idversioni = 1");
@@ -520,7 +546,7 @@ else echo ucfirst(mex("file copiato",$pag)).".<br>";
 
 if ($ripristina_backup and $id_utente == 1) {
 if ($backup_contratti != "SI") {
-if (C_BACKUP_E_MODELLI_CON_NUOVI_DATI == "NO") $dati_conn = "attuali";
+if (defined('C_BACKUP_E_MODELLI_CON_NUOVI_DATI') and C_BACKUP_E_MODELLI_CON_NUOVI_DATI == "NO") $dati_conn = "attuali";
 $file = C_DATI_PATH."/hoteld_backup.php";
 if (@is_file($file)) {
 if ($fbackup = fopen($file,"r")) {
@@ -536,10 +562,10 @@ break;
 } # fine if (substr($linea,0,10) == "<versione>")
 } # fine while (!feof($fbackup))
 fclose($fbackup);
-if ($prova = @fopen(C_DATI_PATH."/prova","w+")) {
+if ($prova = @fopen(C_DATI_PATH."/prova","w")) {
 fclose($prova);
 @unlink(C_DATI_PATH."/prova");
-} # fine if ($prova = @fopen(C_DATI_PATH."/prova","w+"))
+} # fine if ($prova = @fopen(C_DATI_PATH."/prova","w"))
 else $dati_scrivibile = "NO";
 if ($versione_file and $versione_file == $versione_corrente) {
 if ($dati_scrivibile != "NO") {
@@ -619,7 +645,7 @@ $N_PHPR_LOAD_EXT = $PHPR_LOAD_EXT;
 $N_PHPR_TAB_PRE = $PHPR_TAB_PRE;
 } # fine if ($dati_conn == "attuali")
 
-if ($continua == "SI" and (C_RESTRIZIONI_DEMO_ADMIN != "SI" or C_PASS_DEMO_ADMIN == $pass_demo_admin)) ripristina_backup($file,"NO",$pag,$numconnessione,$database_esistente,$tempdatabase,$PHPR_DB_TYPE,$PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT,$PHPR_TAB_PRE,$N_PHPR_DB_TYPE,$N_PHPR_DB_NAME,$N_PHPR_DB_HOST,$N_PHPR_DB_PORT,$N_PHPR_DB_USER,$N_PHPR_DB_PASS,$N_PHPR_LOAD_EXT,$N_PHPR_TAB_PRE,$ext_pgsql_caricata,$ext_mysql_caricata,$mantieni_anni);
+if ($continua == "SI" and ((!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") or (defined('C_PASS_DEMO_ADMIN') and C_PASS_DEMO_ADMIN == $pass_demo_admin))) ripristina_backup($file,"NO",$pag,$numconnessione,$database_esistente,$tempdatabase,$PHPR_DB_TYPE,$PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT,$PHPR_TAB_PRE,$N_PHPR_DB_TYPE,$N_PHPR_DB_NAME,$N_PHPR_DB_HOST,$N_PHPR_DB_PORT,$N_PHPR_DB_USER,$N_PHPR_DB_PASS,$N_PHPR_LOAD_EXT,$N_PHPR_TAB_PRE,$ext_pgsql_caricata,$ext_mysql_caricata,$mantieni_anni);
 
 } # fine if ($dati_scrivibile != "NO")
 else echo mex("Non ho i permessi di scrittura sulla cartella dati",$pag).".<br>";
@@ -636,7 +662,7 @@ else {
 if (@is_file(C_DATI_PATH."/hoteld_doc_backup.php")) {
 if ($linee_backup = file(C_DATI_PATH."/hoteld_doc_backup.php")) {
 
-if (C_RESTRIZIONI_DEMO_ADMIN != "SI") ripristina_backup_contr($linee_backup,"NO",$pag,$PHPR_TAB_PRE,$modalita,$contr_agg);
+if (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI") ripristina_backup_contr($linee_backup,"NO",$pag,$PHPR_TAB_PRE,$modalita,$contr_agg);
 
 } # fine if ($linee_backup = file(C_DATI_PATH."/hoteld_doc_backup.php"))
 else echo mex("Non ho potuto leggere il file",$pag).".<br>";
@@ -808,7 +834,7 @@ else {
 
 
 # Pagina iniziale di backup
-if (C_NASCONDI_MARCA == "SI") echo "<h3 id=\"h_bkup\"><span>".mex("Sistema di backup","personalizza.php").".</span></h3>";
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") echo "<h3 id=\"h_bkup\"><span>".mex("Sistema di backup","personalizza.php").".</span></h3>";
 else echo "<h3 id=\"h_bkup\"><span>".mex("Sistema di backup per HotelDruid",$pag).".</span></h3>";
 echo "<hr style=\"width: 95%\">";
 
@@ -902,7 +928,7 @@ echo "<table><tr><td style=\"width: 30px;\"></td><td>
 <label><input type=\"checkbox\" name=\"mantieni_anni\" value=\"1\">".mex("Prova a mantenere i dati degli anni non contenuti nel backup",$pag)."</label>
  <small>(".mex("alcuni dati di questi anni potrebbero comunque venir persi",$pag).")</small>
 </td></tr></table>";
-if (C_BACKUP_E_MODELLI_CON_NUOVI_DATI != "NO") echo "<div><label><input type=\"radio\" name=\"dati_conn\" value=\"nuovi\">".mex("nuovi dati",$pag)."</label></div>";
+if (!defined('C_BACKUP_E_MODELLI_CON_NUOVI_DATI') or C_BACKUP_E_MODELLI_CON_NUOVI_DATI != "NO") echo "<div><label><input type=\"radio\" name=\"dati_conn\" value=\"nuovi\">".mex("nuovi dati",$pag)."</label></div>";
 echo "</td></tr></table></div></form><table><tr><td style=\"height: 1px;\"></td></tr></table>";
 } # fine if ($file_esistente == "SI")
 } # fine if ($id_utente == 1)
