@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@
 ##################################################################################
 
 
-function crea_quadro_disp ($id_data_inizio_tab_disp,$num_colonne_tab_disp,$mostra_quadro_disp,$mostra_num_liberi,$app_consentito,$app_consentito_sett,$app_regola2_orig,$tipo_periodi,$numero_tariffe,$nome_tariffa,$dati_app,$prenota_in_app_sett,$app_orig_prenota_id,$tableperiodi,$allinea_disp="",$dati_tariffe="") {
+function crea_quadro_disp ($id_data_inizio_tab_disp,$num_colonne_tab_disp,$mostra_quadro_disp,$mostra_num_liberi,$app_consentito,$app_consentito_sett,$app_regola2_orig,$tipo_periodi,$numero_tariffe,$nome_tariffa,$dati_app,$prenota_in_app_sett,$app_orig_prenota_id,$tableperiodi,$allinea_disp="",$dati_tariffe="",$return_var=0) {
 global $c_sfondo_tab_disp,$c_inisett_tab_disp,$c_libero_tab_disp,$c_occupato_tab_disp,$aper_font_tab_disp,$chiu_font_tab_disp,$fr_persone,$fr_persona,$nome_mese,$colonna_destra_tab_disp,$tablepersonalizza,$id_utente,$anno;
 
 if ($tipo_periodi == "s") $colspan = 14;
@@ -36,13 +36,13 @@ if ($mostra_quadro_disp == "app") {
 $mostra_num_liberi = "NO";
 ksort ($dati_app['maxocc']);
 reset ($dati_app['maxocc']);
-while (list($key, $val) = each($dati_app['maxocc'])) {
+foreach ($dati_app['maxocc'] as $key => $val) {
 if ($app_consentito[$key] == "SI") {
 $app_ric_raggr[$num_raggr] = $key;
 $nome_raggr[$num_raggr] = $key;
 $num_raggr++;
 } # fine if ($app_consentito[$numapp] == "SI")
-} # fine while (list($key, $val) = each($dati_app['maxocc']))
+} # fine foreach ($dati_app['maxocc'] as $key => $val)
 } # fine if ($mostra_quadro_disp == "app")
 
 if ($mostra_quadro_disp == "reg2") {
@@ -65,7 +65,7 @@ if ($mostra_quadro_disp == "pers") {
 asort ($dati_app['maxocc']);
 reset ($dati_app['maxocc']);
 $ultime_persone_casa = "vuoto";
-while (list($key, $val) = each($dati_app['maxocc'])) {
+foreach ($dati_app['maxocc'] as $key => $val) {
 $persone_casa = $val;
 if ($persone_casa != $ultime_persone_casa) {
 if ($app_ric_raggr[$num_raggr]) {
@@ -80,7 +80,7 @@ $num_raggr++;
 $ultime_persone_casa = $persone_casa;
 } # fine if ($persone_casa != $ultimepersone_casa)
 if ($app_consentito[$key] == "SI") $app_ric_raggr[$num_raggr] .= "$key,";
-} # fine while (list($key, $val) = each($dati_app[maxocc]))
+} # fine foreach ($dati_app['maxocc'] as $key => $val)
 if ($app_ric_raggr[$num_raggr]) {
 $app_ric_raggr[$num_raggr] = substr($app_ric_raggr[$num_raggr],0,-1);
 if ($ultime_persone_casa) {
@@ -102,7 +102,7 @@ $app_ric_colonna = ",".$app_ric_raggr[$num1].",";
 for ($num2 = 0 ; $num2 < $num_colonne_tab_disp ; $num2++) {
 $id_periodo = $id_data_inizio_tab_disp + $num2;
 $num_app_liberi = $max_app_liberi;
-if ($app_consentito_sett[",attivo,"] == "SI") {
+if ($app_consentito_sett[',attivo,'] == "SI") {
 if ($num2 == 0) {
 $app_ric_col_vett = explode(",",$app_ric_raggr[$num1]);
 $num_app_ric_col = count($app_ric_col_vett);
@@ -114,9 +114,9 @@ $app_ric_colonna = str_replace(",".$app_ric_col_vett[$num3].",",",",$app_ric_col
 $num_app_liberi--;
 } # fine if ($app_consentito_sett[$app_ric_col_vett[$num3]][$id_periodo] != "SI")
 } # fine for $num3
-} # fine if ($app_consentito_sett[",attivo,"] == "SI")
-$pren_pres_in_lista = "";
-$lista_prenota_periodo = "";
+} # fine if ($app_consentito_sett[',attivo,'] == "SI")
+$pren_pres_in_lista = array();
+$lista_prenota_periodo = array();
 $num_lista_pren_per = 0;
 lista_prenota_periodo($id_periodo,$id_periodo,$dati_app,$prenota_in_app_sett,$pren_pres_in_lista,$lista_prenota_periodo,$num_lista_pren_per);
 for ($num3 = 0 ; $num3 < $num_lista_pren_per ; $num3++) {
@@ -131,6 +131,7 @@ else $val_liberi = "&nbsp;";
 if ($num2 == 0 and $allinea_disp == "SI") $colspan_v = $colspan / 2;
 else $colspan_v = $colspan;
 $righe_tab_disp .= "<td style=\"background-color: $color;\" colspan=\"$colspan_v\">$aper_font_tab_disp$val_liberi$chiu_font_tab_disp</td>";
+if ($return_var) $tab_liberi[$nome_raggr[$num1]][$id_periodo] = $num_app_liberi;
 } # fine for $num2
 
 if ($colonna_destra_tab_disp != "NO") $righe_tab_disp .= "<td>$aper_font_tab_disp".$nome_raggr[$num1]."$chiu_font_tab_disp</td></tr>";
@@ -138,6 +139,9 @@ else $righe_tab_disp .= "</tr>";
 } # fine if ($app_ric_raggr[$num1])
 } # fine for $num1
 
+if ($return_var) return $tab_liberi;
+
+
 if ($righe_tab_disp) {
 
 if ($tipo_periodi == "s") $ripeti_giorni = 7;
@@ -216,5 +220,77 @@ return $righe_tab_disp;
 
 
 
+function trova_app_consentiti_per_tab_disp (&$app_consentito,&$app_consentito_sett,&$quadro_non_preciso,$dati_app,$dati_tariffe,$id_data_inizio_tab_disp,$num_colonne_tab_disp,$dati_r2,$attiva_regole1_consentite,$fuori_da_regole1,$regole1_consentite,$condizioni_regole1_consentite,$tariffe_mostra,$attiva_tariffe_consentite,$tariffe_consentite_vett,$priv_mod_assegnazione_app,$priv_mod_prenotazioni,$priv_ins_assegnazione_app,$priv_ins_nuove_prenota,$tableregole) {
+
+$app_consentito = array();
+$app_consentito_sett = array();
+
+# Calcolo gli appartamenti consentiti dalla regola 1
+if ($attiva_regole1_consentite == "s") {
+$app_consentito_sett[',attivo,'] = "SI";
+if ($fuori_da_regole1) {
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
+$app_consentito[$dati_app['posizione'][$num1]] = "SI";
+for ($num2 = $id_data_inizio_tab_disp ; $num2 <= ($id_data_inizio_tab_disp + $num_colonne_tab_disp - 1) ; $num2++) {
+$app_consentito_sett[$dati_app['posizione'][$num1]][$num2] = "SI";
+} # fine for $num2
+} # fine for $num1
+} # fine if ($fuori_da_regole1)
+$quadro_non_preciso = "SI";
+if (!$regole1_consentite) $regole1_consentite = esegui_query("select idregole,app_agenzia,iddatainizio,iddatafine from $tableregole where app_agenzia != '' and $condizioni_regole1_consentite");
+$num_regole1_consentite = numlin_query($regole1_consentite);
+for ($num1 = 0 ; $num1 < $num_regole1_consentite ; $num1++) {
+$idapp = risul_query($regole1_consentite,$num1,'app_agenzia');
+if (!$fuori_da_regole1) $app_consentito[$idapp] = "SI";
+$iddatainizio_reg1 = risul_query($regole1_consentite,$num1,'iddatainizio');
+$iddatafine_reg1 = risul_query($regole1_consentite,$num1,'iddatafine');
+for ($num2 =  $iddatainizio_reg1; $num2 <= $iddatafine_reg1 ; $num2++) {
+if (!$fuori_da_regole1) $app_consentito_sett[$idapp][$num2] = "SI";
+else $app_consentito_sett[$idapp][$num2] = "NO";
+} # fine for $num2
+} # fine for $num1
+} # fine if ($attiva_regole1_consentite == "s")
+else for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) $app_consentito[$dati_app['posizione'][$num1]] = "SI";
+
+
+# Calcolo gli appartamenti consentiti dalla regola 2
+if ($tariffe_mostra == "priv" and ($priv_mod_assegnazione_app != "s" or $priv_mod_prenotazioni != "s") and ($priv_ins_assegnazione_app != "s" or $priv_ins_nuove_prenota != "s")) {
+if ($attiva_tariffe_consentite != "n") $tariffe_mostra = $tariffe_consentite_vett;
+else {
+$tariffe_mostra = array();
+for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) $tariffe_mostra[$numtariffa] = "SI";
+} # fine else if ($attiva_tariffe_consentite != "n")
+} # fine if ($tariffe_mostra == "priv" and ($priv_mod_assegnazione_app != "s" or $priv_mod_prenotazioni != "s") and...
+if (is_array($tariffe_mostra)) {
+$tutti_consentiti = "NO";
+$appartamenti_consentiti_regola2 = array();
+for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
+if ($tariffe_mostra[$numtariffa] == "SI") {
+if (!$dati_r2["tariffa$numtariffa"]) {
+echo "$numtariffa QUI<br>";
+$tutti_consentiti = "SI";
+break;
+} # fine if (!$dati_r2["tariffa$numtariffa"])
+else {
+$appartamenti_regola2 = explode(",",$dati_r2["tariffa$numtariffa"]);
+for ($num1 = 0 ; $num1 < count($appartamenti_regola2) ; $num1++) $appartamenti_consentiti_regola2[$appartamenti_regola2[$num1]] = "SI";
+} # fine else if (!$dati_r2["tariffa$numtariffa"])
+} # fine if ($tariffe_mostra[$numtariffa] == "SI")
+} # fine for $numtariffa
+if ($tutti_consentiti != "SI") {
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
+$idapp = $dati_app['posizione'][$num1];
+if ($appartamenti_consentiti_regola2[$idapp] != "SI") {
+$app_consentito[$idapp] = "NO";
+$quadro_non_preciso = "SI";
+} # fine if ($appartamenti_consentiti_regola2[$idapp] != "SI")
+} # fine for $num1
+} # fine if ($tutti_consentiti != "SI")
+} # fine if (is_array($tariffe_mostra))
+
+} # fine function trova_app_consentiti_per_tab_disp
+
+
+
 
 ?>
\ No newline at end of file
