@@ -411,16 +411,18 @@ case "adulto":  				$messaggio = "adult"; break;
 case "adulti":  				$messaggio = "adults"; break;
 case "bambino":  				$messaggio = "child"; break;
 case "bambini":  				$messaggio = "children"; break;
-case "Numero di categorie delle persone":  	$messaggio = "Number of people categories"; break;
-case "Categoria":  				$messaggio = "Category"; break;
+case "Numero di tipologie di persone":  	$messaggio = "Number of people types"; break;
+case "Tipologia":  				$messaggio = "Type"; break;
 case "Può essere ospite principale":  		$messaggio = "Can be main guest"; break;
 case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Price in percentage of per person price"; break;
 case "arrotondato a":  				$messaggio = "rounded to"; break;
-case "Modifica le categorie delle persone":  	$messaggio = "Modify people categories"; break;
-case "Il numero di categorie delle persone è sbagliato":	$messaggio = "The number of people categories is wrong"; break;
-case "Il numero di categorie delle persone è stato cambiato":	$messaggio = "The number of people categories has been changed"; break;
+case "Modifica le tipologie di persone":  	$messaggio = "Modify people types"; break;
+case "Il numero di tipologie di persone è sbagliato":	$messaggio = "The number of people types is wrong"; break;
+case "Il numero di tipologie di persone è stato cambiato":	$messaggio = "The number of people types has been changed"; break;
 case "I dati inseriti non sono corretti":  	$messaggio = "Inserted data are incorrect"; break;
-case "Le categorie delle persone sono state modificate":	$messaggio = "The people categories have been modified"; break;
+case "Le tipologie di persone sono state modificate":	$messaggio = "The people types have been modified"; break;
+case "Cambia per tutti gli utenti":  		$messaggio = "Change for all users"; break;
+case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modify people types for all users"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
