@@ -36,7 +36,7 @@ case "è stato modificato":  			$messaggio = "ha sido modificado"; break;
 case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
 case "Cognome":  				$messaggio = "Apellido"; break;
-case "cambia in":  				$messaggio = "cambia a"; break;
+case "cambia in":  				$messaggio = "cambiar a"; break;
 case "Nome":  					$messaggio = "Nombre"; break;
 case "cancella":  				$messaggio = "borrar"; break;
 case "Sesso":  					$messaggio = "Sexo"; break;
@@ -151,6 +151,12 @@ case "verrà aggiunto":  			$messaggio = "será añadido"; break;
 case "scaduta":  				$messaggio = "caducada"; break;
 case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "Las tarjetas de crédito se podrán ver de nuevo después de cambiar la contraseña"; break;
 case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "Las tarjetas de crédito se podrán ver de nuevo después que el usuario administrador haya cambiado la contraseña"; break;
+case "Login temporaneamente bloccato":  	$messaggio = "Bloqueo temporáneo del login"; break;
+case "NOTA":  					$messaggio = "NOTA"; break;
+case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "este valor ha sido borrado, esta es la última vez que será posible verlo"; break;
+case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "Será posible ver este valor solo una vez más"; break;
+case "Cancellalo ora":  			$messaggio = "Borrarlo ahora"; break;
+case "CVC cancellato":  			$messaggio = "CVC borrado"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
