@@ -411,16 +411,18 @@ case "adulto":  				$messaggio = "adulto"; break;
 case "adulti":  				$messaggio = "adultos"; break;
 case "bambino":  				$messaggio = "niño"; break;
 case "bambini":  				$messaggio = "niños"; break;
-case "Numero di categorie delle persone":  	$messaggio = "Número de categorías de personas"; break;
-case "Categoria":  				$messaggio = "Categoría"; break;
+case "Numero di tipologie di persone":  	$messaggio = "Número de tipos de personas"; break;
+case "Tipologia":  				$messaggio = "Tipo"; break;
 case "Può essere ospite principale":  		$messaggio = "Puede ser huésped principal"; break;
 case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Precio en porcentaje del precio por persona"; break;
 case "arrotondato a":  				$messaggio = "redondeado a"; break;
-case "Modifica le categorie delle persone":  	$messaggio = "Modificar las categorías de personas"; break;
-case "Il numero di categorie delle persone è sbagliato":	$messaggio = "El número de categorías de personas está equivocado"; break;
-case "Il numero di categorie delle persone è stato cambiato":	$messaggio = "El número de categorías de personas ha sido cambiado"; break;
+case "Modifica le tipologie di persone":  	$messaggio = "Modificar los tipos de personas"; break;
+case "Il numero di tipologie di persone è sbagliato":	$messaggio = "El número de tipos de personas está equivocado"; break;
+case "Il numero di tipologie di persone è stato cambiato":	$messaggio = "El número de tipos de personas ha sido cambiado"; break;
 case "I dati inseriti non sono corretti":  	$messaggio = "Los datos insertados no son correctos"; break;
-case "Le categorie delle persone sono state modificate":	$messaggio = "Las categorías de personas han sido modificadas"; break;
+case "Le tipologie di persone sono state modificate":	$messaggio = "Los tipos de personas han sido modificados"; break;
+case "Cambia per tutti gli utenti":  		$messaggio = "Cambiar para todos los usuarios"; break;
+case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modificar los tipos de personas para todos los usuarios"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
