@@ -89,6 +89,10 @@ $trad_var['valore_costo_agg_senza_tasse'] = 'valor_coste_agna_sin_tasas';
 $trad_var['valore_costo_agg_senza_tasse_p'] = 'valor_coste_agna_sin_tasas_p';
 $trad_var['moltiplica_max_costo_agg'] = 'multiplicado_max_coste_agna';
 $trad_var['moltiplica_max_costo_agg_sel'] = 'multiplicado_max_coste_agna_sel';
+$trad_var['valore_giornaliero_max_costo_agg'] = 'valor_diario_max_coste_agna';
+$trad_var['valore_giornaliero_max_costo_agg_p'] = 'valor_diario_max_coste_agna_p';
+$trad_var['valore_giornaliero_max_costo_agg_sel'] = 'valor_diario_max_coste_agna_sel';
+$trad_var['valore_giornaliero_max_costo_agg_sel_p'] = 'valor_diario_max_coste_agna_sel_p';
 $trad_var['data_inserimento_costo_agg'] = 'fecha_insercion_coste_agna';
 $trad_var['utente_inserimento_costo_agg'] = 'usuario_insercion_coste_agna';
 $trad_var['percentuale_tasse_costo_agg_sel'] = 'porcentage_tasas_coste_agna_sel';
