@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,8 +23,8 @@
 
 
 
-$fr_frase = "";
-$frase = "";
+$fr_frase = array();
+$frase = array();
 
 $fr_frase[0] = "fr_in";
 $fr_frase[1] = "fr_Non_c_e_piu_disponibilita";
