@@ -36,7 +36,7 @@ else $c_cartella_crea_mod = "";
 $perc_cart_mod_int = $percorso_cartella_modello;
 $perc_cart_mod_vett = explode(",",$percorso_cartella_modello);
 $num_perc_cart_mod_vett = count($perc_cart_mod_vett);
-$vett_tmp = "";
+$vett_tmp = array();
 $num_vett_tmp = 0;
 for ($num_cart = 0 ; $num_cart < $num_perc_cart_mod_vett ; $num_cart++) {
 if (!$c_cartella_crea_mod or substr($perc_cart_mod_vett[$num_cart]."/",0,strlen($c_cartella_crea_mod."/")) == $c_cartella_crea_mod."/") {
