@@ -107,188 +107,192 @@ $var_predef[80] = "valore_costo_agg_senza_tasse";
 $var_predef[81] = "valore_costo_agg_senza_tasse_p";
 $var_predef[82] = "giorni_costo_agg";
 $var_predef[83] = "moltiplica_max_costo_agg";
-$var_predef[84] = "data_inserimento_costo_agg";
-$var_predef[85] = "utente_inserimento_costo_agg";
-$var_predef[86] = "valore_tutti_costi_agg";
-$var_predef[87] = "valore_tutti_costi_agg_p";
-$var_predef[88] = "tutti_i_costi_agg";
-$var_predef[89] = "tutti_i_costi_agg_p";
-$var_predef[90] = "nome_costo_agg_sel";
-$var_predef[91] = "valore_costo_agg_sel";
-$var_predef[92] = "valore_costo_agg_sel_p";
-$var_predef[93] = "percentuale_tasse_costo_agg_sel";
-$var_predef[94] = "tasse_costo_agg_sel";
-$var_predef[95] = "tasse_costo_agg_sel_p";
-$var_predef[96] = "moltiplica_max_costo_agg_sel";
-$var_predef[97] = "num_costi_aggiuntivi";
-$var_predef[98] = "valore_pagamento";
-$var_predef[99] = "valore_pagamento_p";
-$var_predef[100] = "metodo_pagamento";
-$var_predef[101] = "data_pagamento";
-$var_predef[102] = "utente_pagamento";
-$var_predef[103] = "tutti_i_pagamenti";
-$var_predef[104] = "tutti_i_pagamenti_p";
-$var_predef[105] = "valore_ultimo_pagamento";
-$var_predef[106] = "valore_ultimo_pagamento_p";
-$var_predef[107] = "metodo_ultimo_pagamento";
-$var_predef[108] = "data_ultimo_pagamento";
-$var_predef[109] = "utente_ultimo_pagamento";
-$var_predef[110] = "num_pagamenti";
-$var_predef[111] = "numero_prenotazione";
-$var_predef[112] = "numero_ripetizione_prenotazioni";
-$var_predef[113] = "codice_prenotazione";
-$var_predef[114] = "data_inserimento_prenotazione";
-$var_predef[115] = "utente_inserimento_prenotazione";
-$var_predef[116] = "num_ospiti_tot";
-$var_predef[117] = "numero_ospite";
-$var_predef[118] = "cognome_ospite";
-$var_predef[119] = "nome_ospite";
-$var_predef[120] = "soprannome_ospite";
-$var_predef[121] = "titolo_ospite";
-$var_predef[122] = "sesso_ospite";
-$var_predef[123] = "cittadinanza_ospite";
-$var_predef[124] = "parentela_ospite";
-$var_predef[125] = "data_nascita_ospite";
-$var_predef[126] = "citta_nascita_ospite";
-$var_predef[127] = "regione_nascita_ospite";
-$var_predef[128] = "nazione_nascita_ospite";
-$var_predef[129] = "citta_ospite";
-$var_predef[130] = "regione_ospite";
-$var_predef[131] = "nazione_ospite";
-$var_predef[132] = "via_ospite";
-$var_predef[133] = "via2_ospite";
-$var_predef[134] = "numcivico_ospite";
-$var_predef[135] = "documento_ospite";
-$var_predef[136] = "tipo_documento_ospite";
-$var_predef[137] = "citta_documento_ospite";
-$var_predef[138] = "regione_documento_ospite";
-$var_predef[139] = "nazione_documento_ospite";
-$var_predef[140] = "scadenza_documento_ospite";
-$var_predef[141] = "telefono_ospite";
-$var_predef[142] = "telefono2_ospite";
-$var_predef[143] = "telefono3_ospite";
-$var_predef[144] = "fax_ospite";
-$var_predef[145] = "email_ospite";
-$var_predef[146] = "cap_ospite";
-$var_predef[147] = "codice_fiscale_ospite";
-$var_predef[148] = "partita_iva_ospite";
-$var_predef[149] = "numero_progressivo_documento";
-$var_predef[150] = "nome_unita";
-$var_predef[151] = "casa_unita";
-$var_predef[152] = "piano_unita";
-$var_predef[153] = "capacita_unita";
-$var_predef[154] = "priorita_unita";
-$var_predef[155] = "num_unita";
-$var_predef[156] = "costo_tot_somma_ripetizioni";
-$var_predef[157] = "costo_tot_somma_ripetizioni_p";
-$var_predef[158] = "caparra_somma_ripetizioni";
-$var_predef[159] = "caparra_somma_ripetizioni_p";
-$var_predef[160] = "resto_caparra_somma_ripetizioni";
-$var_predef[161] = "resto_caparra_somma_ripetizioni_p";
-$var_predef[162] = "pagato_somma_ripetizioni";
-$var_predef[163] = "pagato_somma_ripetizioni_p";
-$var_predef[164] = "resto_da_pagare_somma_ripetizioni";
-$var_predef[165] = "resto_da_pagare_somma_ripetizioni_p";
-$var_predef[166] = "num_persone_tot_somma_ripetizioni";
-$var_predef[167] = "codice_cittadinanza";
-$var_predef[168] = "codice_nazione_nascita";
-$var_predef[169] = "codice_regione_nascita";
-$var_predef[170] = "codice_citta_nascita";
-$var_predef[171] = "codice_nazione";
-$var_predef[172] = "codice_regione";
-$var_predef[173] = "codice_citta";
-$var_predef[174] = "codice_tipo_documento";
-$var_predef[175] = "codice_citta_documento";
-$var_predef[176] = "codice_regione_documento";
-$var_predef[177] = "codice_nazione_documento";
-$var_predef[178] = "codice2_cittadinanza";
-$var_predef[179] = "codice2_nazione_nascita";
-$var_predef[180] = "codice2_regione_nascita";
-$var_predef[181] = "codice2_citta_nascita";
-$var_predef[182] = "codice2_nazione";
-$var_predef[183] = "codice2_regione";
-$var_predef[184] = "codice2_citta";
-$var_predef[185] = "codice2_tipo_documento";
-$var_predef[186] = "codice2_citta_documento";
-$var_predef[187] = "codice2_regione_documento";
-$var_predef[188] = "codice2_nazione_documento";
-$var_predef[189] = "codice3_cittadinanza";
-$var_predef[190] = "codice3_nazione_nascita";
-$var_predef[191] = "codice3_regione_nascita";
-$var_predef[192] = "codice3_citta_nascita";
-$var_predef[193] = "codice3_nazione";
-$var_predef[194] = "codice3_regione";
-$var_predef[195] = "codice3_citta";
-$var_predef[196] = "codice3_tipo_documento";
-$var_predef[197] = "codice3_citta_documento";
-$var_predef[198] = "codice3_regione_documento";
-$var_predef[199] = "codice3_nazione_documento";
-$var_predef[200] = "codice_cittadinanza_ospite";
-$var_predef[201] = "codice_parentela_ospite";
-$var_predef[202] = "codice_nazione_nascita_ospite";
-$var_predef[203] = "codice_regione_nascita_ospite";
-$var_predef[204] = "codice_citta_nascita_ospite";
-$var_predef[205] = "codice_nazione_ospite";
-$var_predef[206] = "codice_regione_ospite";
-$var_predef[207] = "codice_citta_ospite";
-$var_predef[208] = "codice_tipo_documento_ospite";
-$var_predef[209] = "codice_citta_documento_ospite";
-$var_predef[210] = "codice_regione_documento_ospite";
-$var_predef[211] = "codice_nazione_documento_ospite";
-$var_predef[212] = "codice2_cittadinanza_ospite";
-$var_predef[213] = "codice2_parentela_ospite";
-$var_predef[214] = "codice2_nazione_nascita_ospite";
-$var_predef[215] = "codice2_regione_nascita_ospite";
-$var_predef[216] = "codice2_citta_nascita_ospite";
-$var_predef[217] = "codice2_nazione_ospite";
-$var_predef[218] = "codice2_regione_ospite";
-$var_predef[219] = "codice2_citta_ospite";
-$var_predef[220] = "codice2_tipo_documento_ospite";
-$var_predef[221] = "codice2_citta_documento_ospite";
-$var_predef[222] = "codice2_regione_documento_ospite";
-$var_predef[223] = "codice2_nazione_documento_ospite";
-$var_predef[224] = "codice3_cittadinanza_ospite";
-$var_predef[225] = "codice3_parentela_ospite";
-$var_predef[226] = "codice3_nazione_nascita_ospite";
-$var_predef[227] = "codice3_regione_nascita_ospite";
-$var_predef[228] = "codice3_citta_nascita_ospite";
-$var_predef[229] = "codice3_nazione_ospite";
-$var_predef[230] = "codice3_regione_ospite";
-$var_predef[231] = "codice3_citta_ospite";
-$var_predef[232] = "codice3_tipo_documento_ospite";
-$var_predef[233] = "codice3_citta_documento_ospite";
-$var_predef[234] = "codice3_regione_documento_ospite";
-$var_predef[235] = "codice3_nazione_documento_ospite";
-$var_predef[236] = "data_inizio_selezione";
-$var_predef[237] = "data_fine_selezione";
-$var_predef[238] = "oggi";
-$var_predef[239] = "utente_attuale";
-$var_predef[240] = "nome_struttura";
-$var_predef[241] = "tipo_struttura";
-$var_predef[242] = "email_struttura";
-$var_predef[243] = "ragione_sociale_struttura";
-$var_predef[244] = "sito_web_struttura";
-$var_predef[245] = "nome_contatto_struttura";
-$var_predef[246] = "nazione_struttura";
-$var_predef[247] = "comune_struttura";
-$var_predef[248] = "indirizzo_struttura";
-$var_predef[249] = "CAP_struttura";
-$var_predef[250] = "telefono_struttura";
-$var_predef[251] = "fax_struttura";
-$var_predef[252] = "codice_fiscale_struttura";
-$var_predef[253] = "partita_iva_struttura";
-$var_predef[254] = "numero_stelle_struttura";
-$var_predef[255] = "logo_struttura";
-$var_predef[256] = "nome_valuta";
-$var_predef[257] = "testo_email_richiesta";
-$var_predef[258] = "testo_quotato_email_richiesta";
-$var_predef[259] = "url_base_pagine_web";
-$var_predef[260] = "ritorno_a_capo";
-$var_predef[261] = "avanzamento_riga";
-$var_predef[262] = "valore_nullo";
-$var_predef[263] = "email_gia_inviata";
-$var_predef[264] = "errore_ripetizione";
-$var_predef[265] = "messaggio_di_errore";
+$var_predef[84] = "valore_giornaliero_max_costo_agg";
+$var_predef[85] = "valore_giornaliero_max_costo_agg_p";
+$var_predef[86] = "data_inserimento_costo_agg";
+$var_predef[87] = "utente_inserimento_costo_agg";
+$var_predef[88] = "valore_tutti_costi_agg";
+$var_predef[89] = "valore_tutti_costi_agg_p";
+$var_predef[90] = "tutti_i_costi_agg";
+$var_predef[91] = "tutti_i_costi_agg_p";
+$var_predef[92] = "nome_costo_agg_sel";
+$var_predef[93] = "valore_costo_agg_sel";
+$var_predef[94] = "valore_costo_agg_sel_p";
+$var_predef[95] = "percentuale_tasse_costo_agg_sel";
+$var_predef[96] = "tasse_costo_agg_sel";
+$var_predef[97] = "tasse_costo_agg_sel_p";
+$var_predef[98] = "moltiplica_max_costo_agg_sel";
+$var_predef[99] = "valore_giornaliero_max_costo_agg_sel";
+$var_predef[100] = "valore_giornaliero_max_costo_agg_sel_p";
+$var_predef[101] = "num_costi_aggiuntivi";
+$var_predef[102] = "valore_pagamento";
+$var_predef[103] = "valore_pagamento_p";
+$var_predef[104] = "metodo_pagamento";
+$var_predef[105] = "data_pagamento";
+$var_predef[106] = "utente_pagamento";
+$var_predef[107] = "tutti_i_pagamenti";
+$var_predef[108] = "tutti_i_pagamenti_p";
+$var_predef[109] = "valore_ultimo_pagamento";
+$var_predef[110] = "valore_ultimo_pagamento_p";
+$var_predef[111] = "metodo_ultimo_pagamento";
+$var_predef[112] = "data_ultimo_pagamento";
+$var_predef[113] = "utente_ultimo_pagamento";
+$var_predef[114] = "num_pagamenti";
+$var_predef[115] = "numero_prenotazione";
+$var_predef[116] = "numero_ripetizione_prenotazioni";
+$var_predef[117] = "codice_prenotazione";
+$var_predef[118] = "data_inserimento_prenotazione";
+$var_predef[119] = "utente_inserimento_prenotazione";
+$var_predef[120] = "num_ospiti_tot";
+$var_predef[121] = "numero_ospite";
+$var_predef[122] = "cognome_ospite";
+$var_predef[123] = "nome_ospite";
+$var_predef[124] = "soprannome_ospite";
+$var_predef[125] = "titolo_ospite";
+$var_predef[126] = "sesso_ospite";
+$var_predef[127] = "cittadinanza_ospite";
+$var_predef[128] = "parentela_ospite";
+$var_predef[129] = "data_nascita_ospite";
+$var_predef[130] = "citta_nascita_ospite";
+$var_predef[131] = "regione_nascita_ospite";
+$var_predef[132] = "nazione_nascita_ospite";
+$var_predef[133] = "citta_ospite";
+$var_predef[134] = "regione_ospite";
+$var_predef[135] = "nazione_ospite";
+$var_predef[136] = "via_ospite";
+$var_predef[137] = "via2_ospite";
+$var_predef[138] = "numcivico_ospite";
+$var_predef[139] = "documento_ospite";
+$var_predef[140] = "tipo_documento_ospite";
+$var_predef[141] = "citta_documento_ospite";
+$var_predef[142] = "regione_documento_ospite";
+$var_predef[143] = "nazione_documento_ospite";
+$var_predef[144] = "scadenza_documento_ospite";
+$var_predef[145] = "telefono_ospite";
+$var_predef[146] = "telefono2_ospite";
+$var_predef[147] = "telefono3_ospite";
+$var_predef[148] = "fax_ospite";
+$var_predef[149] = "email_ospite";
+$var_predef[150] = "cap_ospite";
+$var_predef[151] = "codice_fiscale_ospite";
+$var_predef[152] = "partita_iva_ospite";
+$var_predef[153] = "numero_progressivo_documento";
+$var_predef[154] = "nome_unita";
+$var_predef[155] = "casa_unita";
+$var_predef[156] = "piano_unita";
+$var_predef[157] = "capacita_unita";
+$var_predef[158] = "priorita_unita";
+$var_predef[159] = "num_unita";
+$var_predef[160] = "costo_tot_somma_ripetizioni";
+$var_predef[161] = "costo_tot_somma_ripetizioni_p";
+$var_predef[162] = "caparra_somma_ripetizioni";
+$var_predef[163] = "caparra_somma_ripetizioni_p";
+$var_predef[164] = "resto_caparra_somma_ripetizioni";
+$var_predef[165] = "resto_caparra_somma_ripetizioni_p";
+$var_predef[166] = "pagato_somma_ripetizioni";
+$var_predef[167] = "pagato_somma_ripetizioni_p";
+$var_predef[168] = "resto_da_pagare_somma_ripetizioni";
+$var_predef[169] = "resto_da_pagare_somma_ripetizioni_p";
+$var_predef[170] = "num_persone_tot_somma_ripetizioni";
+$var_predef[171] = "codice_cittadinanza";
+$var_predef[172] = "codice_nazione_nascita";
+$var_predef[173] = "codice_regione_nascita";
+$var_predef[174] = "codice_citta_nascita";
+$var_predef[175] = "codice_nazione";
+$var_predef[176] = "codice_regione";
+$var_predef[177] = "codice_citta";
+$var_predef[178] = "codice_tipo_documento";
+$var_predef[179] = "codice_citta_documento";
+$var_predef[180] = "codice_regione_documento";
+$var_predef[181] = "codice_nazione_documento";
+$var_predef[182] = "codice2_cittadinanza";
+$var_predef[183] = "codice2_nazione_nascita";
+$var_predef[184] = "codice2_regione_nascita";
+$var_predef[185] = "codice2_citta_nascita";
+$var_predef[186] = "codice2_nazione";
+$var_predef[187] = "codice2_regione";
+$var_predef[188] = "codice2_citta";
+$var_predef[189] = "codice2_tipo_documento";
+$var_predef[190] = "codice2_citta_documento";
+$var_predef[191] = "codice2_regione_documento";
+$var_predef[192] = "codice2_nazione_documento";
+$var_predef[193] = "codice3_cittadinanza";
+$var_predef[194] = "codice3_nazione_nascita";
+$var_predef[195] = "codice3_regione_nascita";
+$var_predef[196] = "codice3_citta_nascita";
+$var_predef[197] = "codice3_nazione";
+$var_predef[198] = "codice3_regione";
+$var_predef[199] = "codice3_citta";
+$var_predef[200] = "codice3_tipo_documento";
+$var_predef[201] = "codice3_citta_documento";
+$var_predef[202] = "codice3_regione_documento";
+$var_predef[203] = "codice3_nazione_documento";
+$var_predef[204] = "codice_cittadinanza_ospite";
+$var_predef[205] = "codice_parentela_ospite";
+$var_predef[206] = "codice_nazione_nascita_ospite";
+$var_predef[207] = "codice_regione_nascita_ospite";
+$var_predef[208] = "codice_citta_nascita_ospite";
+$var_predef[209] = "codice_nazione_ospite";
+$var_predef[210] = "codice_regione_ospite";
+$var_predef[211] = "codice_citta_ospite";
+$var_predef[212] = "codice_tipo_documento_ospite";
+$var_predef[213] = "codice_citta_documento_ospite";
+$var_predef[214] = "codice_regione_documento_ospite";
+$var_predef[215] = "codice_nazione_documento_ospite";
+$var_predef[216] = "codice2_cittadinanza_ospite";
+$var_predef[217] = "codice2_parentela_ospite";
+$var_predef[218] = "codice2_nazione_nascita_ospite";
+$var_predef[219] = "codice2_regione_nascita_ospite";
+$var_predef[220] = "codice2_citta_nascita_ospite";
+$var_predef[221] = "codice2_nazione_ospite";
+$var_predef[222] = "codice2_regione_ospite";
+$var_predef[223] = "codice2_citta_ospite";
+$var_predef[224] = "codice2_tipo_documento_ospite";
+$var_predef[225] = "codice2_citta_documento_ospite";
+$var_predef[226] = "codice2_regione_documento_ospite";
+$var_predef[227] = "codice2_nazione_documento_ospite";
+$var_predef[228] = "codice3_cittadinanza_ospite";
+$var_predef[229] = "codice3_parentela_ospite";
+$var_predef[230] = "codice3_nazione_nascita_ospite";
+$var_predef[231] = "codice3_regione_nascita_ospite";
+$var_predef[232] = "codice3_citta_nascita_ospite";
+$var_predef[233] = "codice3_nazione_ospite";
+$var_predef[234] = "codice3_regione_ospite";
+$var_predef[235] = "codice3_citta_ospite";
+$var_predef[236] = "codice3_tipo_documento_ospite";
+$var_predef[237] = "codice3_citta_documento_ospite";
+$var_predef[238] = "codice3_regione_documento_ospite";
+$var_predef[239] = "codice3_nazione_documento_ospite";
+$var_predef[240] = "data_inizio_selezione";
+$var_predef[241] = "data_fine_selezione";
+$var_predef[242] = "oggi";
+$var_predef[243] = "utente_attuale";
+$var_predef[244] = "nome_struttura";
+$var_predef[245] = "tipo_struttura";
+$var_predef[246] = "email_struttura";
+$var_predef[247] = "ragione_sociale_struttura";
+$var_predef[248] = "sito_web_struttura";
+$var_predef[249] = "nome_contatto_struttura";
+$var_predef[250] = "nazione_struttura";
+$var_predef[251] = "comune_struttura";
+$var_predef[252] = "indirizzo_struttura";
+$var_predef[253] = "CAP_struttura";
+$var_predef[254] = "telefono_struttura";
+$var_predef[255] = "fax_struttura";
+$var_predef[256] = "codice_fiscale_struttura";
+$var_predef[257] = "partita_iva_struttura";
+$var_predef[258] = "numero_stelle_struttura";
+$var_predef[259] = "logo_struttura";
+$var_predef[260] = "nome_valuta";
+$var_predef[261] = "testo_email_richiesta";
+$var_predef[262] = "testo_quotato_email_richiesta";
+$var_predef[263] = "url_base_pagine_web";
+$var_predef[264] = "ritorno_a_capo";
+$var_predef[265] = "avanzamento_riga";
+$var_predef[266] = "valore_nullo";
+$var_predef[267] = "email_gia_inviata";
+$var_predef[268] = "errore_ripetizione";
+$var_predef[269] = "messaggio_di_errore";
 
 $num_var_predef = count($var_predef);
 $num_var_non_ripeti = 117;
