@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -177,16 +177,20 @@ echo "<table class=\"buttonbar\"><tr><td align=\"left\">
 <input type=\"hidden\" name=\"metodo_selezionato\" value=\"$metodo_selezionato\">
 <input class=\"sbutton\" type=\"submit\" name=\"cerca_prenota\" value=\"".mex("Vedi le modifiche",$pag)."\">
  ".mex("dal",$pag)." <select name=\"cerca_inizioperiodo\">
-<option value=\"\" selected>----</option>";
+<option value=\"\">----</option>";
+$oggi = date("-m-d",(time() + (C_DIFF_ORE * 3600)));
+$domani = date("-m-d",(time() + (C_DIFF_ORE * 3600) + 86400));
 $anno_prec = $anno - 1;
 $anno_succ = $anno + 1;
 $numgiorno = 1;
 do {
-$data_select = date("-m-d " , mktime(0,0,0,1,$numgiorno,$anno));
+$data_select = date("-m-d" , mktime(0,0,0,1,$numgiorno,$anno));
 $data_select_vedi = date("d-m" , mktime(0,0,0,1,$numgiorno,$anno));
 $numgiorno++;
 $annocreato = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
-echo "<option value=\"$data_select\">$data_select_vedi</option>";
+if ($data_select == $oggi) $sel = " selected";
+else $sel = "";
+echo "<option value=\"$data_select\"$sel>$data_select_vedi</option>";
 } while ($annocreato == $anno);
 echo "</select>
 <select name=\"cerca_anno_inizioperiodo\">
@@ -195,14 +199,16 @@ echo "</select>
 <option value=\"$anno_succ\">$anno_succ</option>
 </select>
  ".mex("al",$pag)." <select name=\"cerca_fineperiodo\">
-<option value=\"\" selected>----</option>";
+<option value=\"\">----</option>";
 $numgiorno = 1;
 do {
 $data_select = date("-m-d" , mktime(0,0,0,1,$numgiorno,$anno));
 $data_select_vedi = date("d-m" , mktime(0,0,0,1,$numgiorno,$anno));
 $numgiorno++;
 $annocreato = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
-echo "<option value=\"$data_select\">$data_select_vedi</option>";
+if ($data_select == $domani) $sel = " selected";
+else $sel = "";
+echo "<option value=\"$data_select\"$sel>$data_select_vedi</option>";
 } while ($annocreato == $anno);
 echo "</select>
 <select name=\"cerca_anno_fineperiodo\">
@@ -280,7 +286,7 @@ if ($priv_vedi_tab_costi == "p" or $priv_vedi_tab_costi == "g") {
 $condizione_variazioni_proprie = "and ( utente_inserimento = '$id_utente'";
 if ($priv_vedi_tab_costi == "g") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_variazioni_proprie .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_variazioni_proprie .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_vedi_tab_costi == "g")
 $condizione_variazioni_proprie .= " )";
 } # fine if ($priv_vedi_tab_costi == "p" or $priv_vedi_tab_costi == "g")
@@ -324,7 +330,8 @@ $stringa_puntini_tab = "<tr><td colspan=\"$colonne\">...</td></tr>";
 else $pagina_prenota = 1;
 } # fine if (!$cerca_prenota)
 
-echo "<table class=\"t1\" style=\"background-color: $colore; margin-left: auto; margin-right: auto;\" width=200 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
+echo "<div class=\"tab_cont\">
+<table class=\"t1\" style=\"background-color: $colore; margin-left: auto; margin-right: auto;\" width=200 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
 <tr><td colspan=4>".mex("Dati della prenotazione",$pag)."</td>
 <td rowspan=2>".mex("Pagato prima",$pag)."</td>
 <td rowspan=2>".mex("Pagato dopo",$pag)."</td>
@@ -457,7 +464,7 @@ echo "<td>&nbsp;</td>
 <td>&nbsp;</td></tr>";
 } # fine if ($costo_cassa and !$cerca_prenota)
 
-echo "</table>
+echo "</table></div>
 $stringa_pagine
 
 <br>
