@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -296,6 +296,7 @@ $mese_succ = $mese + 1;
 echo "&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"tabella2.php?anno=$anno&amp;id_sessione=$id_sessione&amp;mese=$mese_succ\">--&gt;</a>";
 } # fine if ($mese != 12)
 echo "</td></tr></table>
+<div class=\"tab_cont\">
 <table style=\"margin-left: auto; margin-right: auto;\" border=1 cellspacing=0 cellpadding=1>";
 $mese_inizio_tab = $mese2;
 $data_inizio_tab = date("Y-m-d" , mktime(0,0,0,$mese_inizio_tab,1,$anno));
@@ -333,7 +334,7 @@ if ($priv_vedi_tab_mesi == "p") {
 $query_prenota_app_canc .= " and ( utente_inserimento = '$id_utente'";
 if ($priv_prenota_gruppi == "SI") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $query_prenota_app_canc .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $query_prenota_app_canc .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_prenota_gruppi == "SI")
 $query_prenota_app_canc .= " )";
 } # fine if ($priv_vedi_tab_mesi == "p")
@@ -400,7 +401,7 @@ if ($priv_vedi_tab_mesi == "p") {
 $condizione_prenota_propria = " and ( utente_inserimento = '$id_utente'";
 if ($priv_prenota_gruppi == "SI") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_prenota_propria .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_prenota_propria .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_prenota_gruppi == "SI")
 $condizione_prenota_propria .= " )";
 } # fine if ($priv_vedi_tab_mesi == "p")
@@ -620,7 +621,7 @@ else $num_ripeti++;
 } # fine if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO") {
 } # fine for $num1
 
-echo "</table>";
+echo "</table></div>";
 
 } # fine for $mese2
 
