@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -297,6 +297,7 @@ $mese_avanti = $mese + 1;
 echo "&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"tabella3.php?anno=$anno&amp;id_sessione=$id_sessione&amp;mese=$mese_avanti\">--></a>";
 } # fine if ($mese != 25)
 echo "</td></tr></table>
+<div class=\"tab_cont\">
 <table class=\"m2\" style=\"margin-left: auto; margin-right: auto;\" border=2 cellspacing=0 cellpadding=1>";
 if ($mese2 != 1 and $tipo_periodi != "g") { $mese_inizio_tab = $mese2 - 1; }
 else { $mese_inizio_tab = $mese2; }
@@ -328,7 +329,7 @@ if ($priv_vedi_tab_mesi == "p") {
 $query_prenota_app_canc .= " and ( utente_inserimento = '$id_utente'";
 if ($priv_prenota_gruppi == "SI") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $query_prenota_app_canc .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $query_prenota_app_canc .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_prenota_gruppi == "SI")
 $query_prenota_app_canc .= " )";
 } # fine if ($priv_vedi_tab_mesi == "p")
@@ -394,7 +395,7 @@ if ($priv_vedi_tab_mesi == "p") {
 $condizione_prenota_propria = " and ( utente_inserimento = '$id_utente'";
 if ($priv_prenota_gruppi == "SI") {
 reset($utenti_gruppi);
-while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $condizione_prenota_propria .= " or utente_inserimento = '$idut_gr'";
+foreach ($utenti_gruppi as $idut_gr => $val) if ($idut_gr != $id_utente) $condizione_prenota_propria .= " or utente_inserimento = '$idut_gr'";
 } # fine if ($priv_prenota_gruppi == "SI")
 $condizione_prenota_propria .= " )";
 } # fine if ($priv_vedi_tab_mesi == "p")
@@ -612,7 +613,7 @@ else $num_ripeti++;
 } # fine if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO")
 } # fine for $num1
 
-echo "</table>";
+echo "</table></div>";
 } # fine for $mese2
 
 
