@@ -83,7 +83,15 @@ $priv_vedi_tab_doc = substr($priv_vedi_tab,7,1);
 $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
 if ($priv_mod_prenotazioni == "g") $prendi_gruppi = "SI";
+$priv_mod_tariffa = substr($priv_mod_prenota,3,1);
+$priv_mod_sconto = substr($priv_mod_prenota,6,1);
+$priv_mod_caparra = substr($priv_mod_prenota,7,1);
+$priv_mod_costi_agg = substr($priv_mod_prenota,8,1);
+$priv_mod_utente_ins = substr($priv_mod_prenota,9,1);
+$priv_mod_pagato = substr($priv_mod_prenota,10,1);
 $priv_mod_codice = substr($priv_mod_prenota,21,1);
+$priv_vedi_commento = substr($priv_mod_prenota,25,1);
+$priv_vedi_commenti_pers = substr($priv_mod_prenota,26,1);
 $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 $vedi_clienti = "NO";
 if (substr($priv_ins_clienti,2,1) == "s") $vedi_clienti = "SI";
@@ -122,6 +130,12 @@ $priv_vedi_tab_costi = "s";
 $priv_vedi_tab_prenotazioni = "s";
 $priv_vedi_tab_doc = "s";
 $priv_mod_prenotazioni = "s";
+$priv_mod_tariffa = "s";
+$priv_mod_sconto = "s";
+$priv_mod_caparra = "s";
+$priv_mod_costi_agg = "s";
+$priv_mod_utente_ins = "s";
+$priv_mod_pagato = "s";
 $priv_mod_codice = "s";
 $vedi_clienti = "SI";
 $priv_vedi_telefoni = "s";
